#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 pandoc-lua-engine
version:              0.4
visibility:           public
id:                   pandoc-lua-engine-0.4-83o1iXwauBTBdAqWP7Z8Fh
key:                  pandoc-lua-engine-0.4-83o1iXwauBTBdAqWP7Z8Fh
license:              GPL-2.0-or-later
copyright:            © 2006-2024 John MacFarlane, 2017-2024 Albert Krewinkel
maintainer:           Albert Krewinkel <albert@hslua.org>
author:               John MacFarlane, Albert Krewinkel
homepage:             https://pandoc.org
synopsis:             Lua engine to power custom pandoc conversions
description:
    This package provides a pandoc scripting engine based on
    Lua.

category:             Text
abi:                  ca10e7837c374a24664c3ebc54714640
exposed:              True
exposed-modules:      Text.Pandoc.Lua
hidden-modules:
    Text.Pandoc.Lua.Custom Text.Pandoc.Lua.Engine
    Text.Pandoc.Lua.Filter Text.Pandoc.Lua.Global Text.Pandoc.Lua.Init
    Text.Pandoc.Lua.Module Text.Pandoc.Lua.Marshal.Chunks
    Text.Pandoc.Lua.Marshal.CommonState Text.Pandoc.Lua.Marshal.Context
    Text.Pandoc.Lua.Marshal.Format Text.Pandoc.Lua.Marshal.ImageSize
    Text.Pandoc.Lua.Marshal.LogMessage
    Text.Pandoc.Lua.Marshal.PandocError
    Text.Pandoc.Lua.Marshal.ReaderOptions
    Text.Pandoc.Lua.Marshal.Reference Text.Pandoc.Lua.Marshal.Sources
    Text.Pandoc.Lua.Marshal.Template
    Text.Pandoc.Lua.Marshal.WriterOptions Text.Pandoc.Lua.Module.CLI
    Text.Pandoc.Lua.Module.Format Text.Pandoc.Lua.Module.Image
    Text.Pandoc.Lua.Module.JSON Text.Pandoc.Lua.Module.Log
    Text.Pandoc.Lua.Module.MediaBag Text.Pandoc.Lua.Module.Pandoc
    Text.Pandoc.Lua.Module.Scaffolding Text.Pandoc.Lua.Module.Structure
    Text.Pandoc.Lua.Module.System Text.Pandoc.Lua.Module.Template
    Text.Pandoc.Lua.Module.Text Text.Pandoc.Lua.Module.Types
    Text.Pandoc.Lua.Module.Utils Text.Pandoc.Lua.Orphans
    Text.Pandoc.Lua.PandocLua Text.Pandoc.Lua.Run
    Text.Pandoc.Lua.SourcePos Text.Pandoc.Lua.Writer.Classic
    Text.Pandoc.Lua.Writer.Scaffolding

import-dirs:          /usr/lib/ghc-9.6.6/site-local/pandoc-lua-engine-0.4
library-dirs:         /usr/lib/ghc-9.6.6/site-local/pandoc-lua-engine-0.4
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/pandoc-lua-engine-0.4
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-pandoc-lua-engine
hs-libraries:         HSpandoc-lua-engine-0.4-83o1iXwauBTBdAqWP7Z8Fh
depends:
    aeson-2.2.1.0-IFj7FSeQ5R79PZnh3ksXrW base-4.18.2.1
    bytestring-0.11.5.3 citeproc-0.8.1.1-ASyzCwsGznZLB8ouWUFvU3
    containers-0.6.7 crypton-1.0.4-BW3r2zHLDkn5MXOxLzl4Qy
    data-default-0.7.1.3-EtVHsfbH5oIpJ9umzYHUz
    doclayout-0.5-KjnKi2Ux4oIGbAAgAzLZAm
    doctemplates-0.11.0.1-xZB2gwaSK33AP5NbkMsEU exceptions-0.10.7
    hslua-2.3.0-JSqG4GDty919hOY05SUyI4
    hslua-module-doclayout-1.2.0-F0hJACG1uP7FngXL0aNs30
    hslua-module-path-1.1.1-kSvjVrRV0Q9AxNumav5BA
    hslua-module-system-1.1.2-8Uw7Ijj9OdJMm6Bb9Yycr
    hslua-module-text-1.1.0.1-2rlqXbogp6ZLEOFOC1pJZs
    hslua-module-version-1.1.1-CnrxV18FFYGAXpbV46o6eq
    hslua-module-zip-1.1.3-7tfcEnuDwRVKclytHkwiYa
    hslua-repl-0.1.2-FjmfJb6stdoDzCDIrDuzsY
    lpeg-1.1.0-HUZNYjnjmFP1vcrfz04RiK mtl-2.3.1
    pandoc-3.6-1DKE0x92VRa5b3GF6kWKcy
    pandoc-lua-marshal-0.3.0-CpWP6YPyqzZIHrMd9h3xOQ
    pandoc-types-1.23.1-7wbk8RCvTUWIER9yMXo060 parsec-3.1.16.1
    text-2.0.2

haddock-interfaces:
    /usr/share/doc/haskell-pandoc-lua-engine/html/pandoc-lua-engine.haddock

haddock-html:         /usr/share/doc/haskell-pandoc-lua-engine/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

